@@ -116,7 +116,7 @@ pub fn execute(
 pub fn try_burn(
     deps: DepsMut,
     env: Env,
-    mut info: MessageInfo,
+    info: MessageInfo,
     amount: Uint128,
 ) -> Result<Response, ContractError> {
     let config = CONFIG.load(deps.storage)?;
@@ -128,7 +128,6 @@ pub fn try_burn(
             expected: config.token_factory_addr,
         });
     }
-    info.sender = deps.api.addr_validate("human")?;
     Ok(execute_burn(deps, env, info, amount)?)
 }
 
