@@ -79,19 +79,58 @@ pub enum ExecuteMsg {
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 #[serde(rename_all = "snake_case")]
 pub enum QueryMsg {
-
     /* Request stored token information */
     TokenConfig { },
 
-    /* Implements CW20. Returns the current balance of the given address, 0 if unset.*/
+    /* Default methods from CW20 Standard with no modifications:
+    https://github.com/CosmWasm/cw-plus/tree/main/contracts/cw20-base */
+
+    /* Returns the current balance of the given address, 0 if unset.
+    Return type: BalanceResponse.*/
     Balance { address: String },
 
-    /* Implements CW20. Returns metadata on the contract - name, decimals, supply, etc.*/
+    /*Returns metadata on the contract - name, decimals, supply, etc.
+    Return type: TokenInfoResponse.*/
     TokenInfo {},
-    
-    /* Implements CW20 "allowance" extension. Returns how much 
-    spender can use from owner account, 0 if unset. */
+
+    /*Only with "mintable" extension.
+    Returns who can mint and the hard cap on maximum tokens after minting.
+    Return type: MinterResponse.*/
+    Minter {},
+
+    /*Only with "allowance" extension.
+    Returns how much spender can use from owner account, 0 if unset.
+    Return type: AllowanceResponse.*/
     Allowance { owner: String, spender: String },
+
+    /*Only with "enumerable" extension (and "allowances")
+    Returns all allowances this owner has approved. Supports pagination.
+    Return type: AllAllowancesResponse.*/
+    AllAllowances {
+        owner: String,
+        start_after: Option<String>,
+        limit: Option<u32>,
+    },
+
+    /*Only with "enumerable" extension
+    Returns all accounts that have balances. Supports pagination.
+    Return type: AllAccountsResponse.*/
+    AllAccounts {
+        start_after: Option<String>,
+        limit: Option<u32>,
+    },
+
+    /*Only with "marketing" extension
+    Returns more metadata on the contract to display in the client:
+    - description, logo, project url, etc.
+    Return type: MarketingInfoResponse*/
+    MarketingInfo {},
+    
+    /*Only with "marketing" extension
+    Downloads the mbeded logo data (if stored on chain). Errors if no logo data ftored for this
+    contract.
+    Return type: DownloadLogoResponse.*/
+    DownloadLogo {},
 }
 
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
